# -*- coding: utf-8 -*-
"""Matomo template tag."""

from django import template
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


register = template.Library()


@register.inclusion_tag('matomo/tracking_code.html')
def tracking_code():
    try:
        id = settings.MATOMO_SITE_ID
    except AttributeError:
        raise ImproperlyConfigured('MATOMO_SITE_ID does not exist.')
    try:
        url = settings.MATOMO_URL
    except AttributeError:
        raise ImproperlyConfigured('MATOMO_URL does not exist.')
    return {'id': id, 'url': url}



import os

from setuptools import setup, find_packages

setup(
    name='django-matomo',
    version='0.1.6',
    description='A simple app to add the Matomo JS tracking code to your template. Forked from `django-piwik`.',
    long_description=open(os.path.join(os.path.dirname(__file__), 'README.rst')).read(),
    author='Mikolaj Buchwald',
    author_email='mikolaj.buchwald@gmail.com',
    url='https://github.com/mikbuch/django-matomo',
    license='BSD License',
    platforms=['OS Independent'],
    packages=find_packages(),
    classifiers=[
        'Environment :: Web Environment',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
    zip_safe=False,
    include_package_data=True,
    install_requires=['Django'],
)
